@@ -35,7 +35,7 @@ your system.
 
 use XSLoader;
 
-our $VERSION = '0.13_90';
+our $VERSION = '0.14_90';
 
 XSLoader::load( __PACKAGE__, $VERSION );
 
@@ -43,9 +43,54 @@ XSLoader::load( __PACKAGE__, $VERSION );
 
 =head1 METHODS
 
-=head2 $obj = I<CLASS>->new()
+=head2 $obj = I<CLASS>->new( %CONFIG_OPTS )
 
-Instantiates I<CLASS>.
+Instantiates I<CLASS>. %CONFIG_OPTS have the same effect as in
+C<configure()> below.
+
+=cut
+
+sub new {
+    my ($class, %opts) = @_;
+
+    my $self = $class->_new();
+
+    return %opts ? $self->configure(%opts) : $self;
+}
+
+=head2 $obj = I<OBJ>->configure( %OPTS )
+
+Tunes the QuickJS interpreter. Returns I<OBJ>.
+
+%OPTS are any of:
+
+=over
+
+=item * C<max_stack_size>
+
+=item * C<memory_limit>
+
+=item * C<gc_threshold>
+
+=back
+
+For more information on these, see QuickJS itself.
+
+=cut
+
+sub configure {
+    my ($self, %opts) = @_;
+
+    my ($stack, $memlimit, $gc_threshold) = delete @opts{'max_stack_size', 'memory_limit', 'gc_threshold'};
+
+    if (my @extra = sort keys %opts) {
+        Carp::croak("Unknown: @extra");
+    }
+
+    return $self->_configure($stack, $memlimit, $gc_threshold);
+}
+
+#----------------------------------------------------------------------
 
 =head2 $obj = I<OBJ>->set_globals( NAME1 => VALUE1, .. )
 
@@ -179,7 +224,8 @@ JavaScript C<RegExp> objects.
 
 If any instance of a class of this distribution is DESTROY()ed at Perl’s
 global destruction, we assume that this is a memory leak, and a warning is
-thrown. To prevent this, avoid circular references.
+thrown. To prevent this, avoid circular references, and clean up all global
+instances.
 
 Callbacks make that tricky. When you give a JavaScript function to Perl,
 that Perl object holds a reference to the QuickJS context. Only once that
